@@ -6,9 +6,11 @@ CLI program for managing packages
 """
 
 import argparse
+from pathlib import Path
+from shutil import copyfile
 
 from metapack import Downloader
-from metapack.cli.core import (MetapackCliMemo, prt, update_name, warn,
+from metapack.cli.core import (MetapackCliMemo, err, prt, update_name, warn,
                                write_doc)
 from metapack_build.core import process_schemas, update_schema_properties
 
@@ -58,6 +60,15 @@ def update(subparsers):
     no Descriptions are set.
 
 
+    -U/--custom-update Runs a puthon function name custom_update(), located
+    in the pylib module. The funcction can recieve the remainder arguments, which
+    can be specified after a '--' argument, if the metatab file is explicitly specified,
+    usually as the current directory, '.'. For instance:
+
+        mp update -U . -- --foo --bar
+
+
+
     """
 
     parser = subparsers.add_parser(
@@ -117,9 +128,21 @@ def update(subparsers):
     parser.add_argument('-G', '--coverage', action='store_true', default=False,
                         help='Calculate spatial and temporal coverage')
 
+    parser.add_argument('-U', '--custom-update', action='store_true', default=False,
+                        help='Run the custom update function, declared in pylib:custom_update')
+
+    parser.add_argument('-t', '--touch', action='store_true', default=False,
+                        help='Update the modification time of the metadata to be the same as the FilesystemPackage, '
+                             'preventing an update build.')
+
+    parser.add_argument('-f', '--files', action='store_true', default=False,
+                        help='Add missing source package files, such as .gitignore, tox.ini, requirements.txt and tasks.py')
+
     parser.add_argument('metatabfile', nargs='?',
                         help="Path or URL to a metatab file. If not provided, defaults to 'metadata.csv' ")
 
+    parser.add_argument('remainder', nargs=argparse.REMAINDER)
+
 
 def run_update(args):
     m = MetapackCliMemo(args, downloader)
@@ -147,6 +170,12 @@ def run_update(args):
     if m.args.promote:
         update_promote(m)
 
+    if m.args.custom_update:
+        update_custom(m)
+
+    if m.args.files:
+        add_files(m)
+
     if m.mtfile_url.scheme == 'file' and m.args.name:
         mod_version = m.args.version if m.args.version \
             else '+' if m.args.increment \
@@ -158,6 +187,9 @@ def run_update(args):
     if m.args.coverage:
         update_coverage(m)
 
+    if m.args.touch:
+        touch_metadata(m)
+
 
 def increment_version(m):
     pass
@@ -322,3 +354,46 @@ def resource_time(r):
 
 def update_coverage(m):
     raise NotImplementedError()
+
+
+def update_custom(m):
+    try:
+        r = m.doc.get_lib_module_dict()
+        r['custom_update'](m.doc, m.args.remainder)
+    except ImportError:
+        err('No custom function')
+
+
+def add_files(m):
+    add_missing_files(m.doc.package_url.fspath)
+
+
+def add_missing_files(package_dir):
+    import metapack_build.support as support_dir
+
+    src_dir = Path(support_dir.__file__).parent
+
+    for src, dest in [('gitignore', '.gitignore'),
+                      ('tox.ini', 'tox.ini'),
+                      ('requirements.txt', 'requirements.txt'),
+                      ('tasks.py', 'tasks.py')]:
+
+        dest_p = Path(package_dir).joinpath(dest)
+
+        if not dest_p.exists():
+            copyfile(src_dir.joinpath(src), dest_p)
+            prt('Creating file: ', dest)
+        else:
+            prt('File exists:', dest)
+
+
+def touch_metadata(m):
+    import os
+
+    p = m.filesystem_package
+
+    t = p.package_build_time()
+
+    os.utime(m.doc.ref.fspath, (t, t))
+
+    prt(f"Set times for '{m.doc.ref.fspath}'' to {t}")
